@@ -115,6 +115,12 @@ TestCommunityProperties <- function()
     AssertRaises(Community(nodes=data.frame(node='S'), 
                            properties=list(xyz='test')))
 
+    # Title in not in lowercase
+    AssertRaises(Community(nodes=data.frame(node='S'), 
+                           properties=list(Title='test')))
+    AssertRaises(Community(nodes=data.frame(node='S'), 
+                           properties=list(TITLE='test')))
+
     # title duplicated
     AssertRaises(Community(nodes=data.frame(node='S'), 
                            properties=list(title='test', title='test')))
@@ -572,7 +578,7 @@ TestRemoveNodes <- function()
     AssertEqual(c1, RemoveNodes(c1, NULL))
     AssertEqual(c1, RemoveNodes(c1, vector(mode='character')))
 
-    AssertEqual(RemoveNodes(c3, 'R', title='c3'), 
+    AssertEqual(RemoveNodes(c3, 1, title='c3'), 
                 RemoveNodes(c3, 'R', title='c3'))
     AssertEqual(c(C='C'), NP(RemoveNodes(c3, 1),'node'))
     AssertEqual(NULL, TLPS(RemoveNodes(c3, 1)))
@@ -598,6 +604,38 @@ TestRemoveNodes <- function()
 
     TL84r <- RemoveNodes(TL84, c('Nostoc sp.', 'Umbra limi'))
     AssertEqual(NPS(TL84)[-c(1,56),],NPS(TL84r))
+
+    # Test secondary and cascade
+    AssertRaises(RemoveNodes(c3, 'R', method='secondary'))
+    AssertRaises(RemoveNodes(c3, 'R', method='cascade'))
+    AssertEqual(c(P='P'), NP(RemoveNodes(c4, 'R', method='secondary'), 'node'))
+    AssertRaises(RemoveNodes(c4, 'R', method='cascade'))
+    AssertEqual(c(O='O'), NP(RemoveNodes(c5, 'R', method='secondary'), 'node'))
+    AssertRaises(RemoveNodes(c5, 'R', method='cascade'))
+    AssertEqual(c(R='R', O='O'), NP(RemoveNodes(c5, 'C', method='secondary'), 'node'))
+    AssertEqual(c(R='R', C='C'), NP(RemoveNodes(c5, 'O', method='secondary'), 'node'))
+    AssertEqual(c(C='C', D='D', E='E'), 
+                NP(RemoveNodes(c7, 'A', method='secondary'), 'node'))
+    AssertEqual(c(D='D', E='E'), 
+                NP(RemoveNodes(c7, 'A', method='cascade'), 'node'))
+    AssertEqual(c(A='A', D='D', E='E'), 
+                NP(RemoveNodes(c7, 'B', method='secondary'), 'node'))
+    AssertEqual(c(A='A', B='B', D='D', E='E'), 
+                NP(RemoveNodes(c7, 'C', method='secondary'), 'node'))
+    AssertEqual(c(A='A', B='B', C='C', E='E'), 
+                NP(RemoveNodes(c7, 'D', method='secondary'), 'node'))
+    AssertEqual(c(A='A', B='B', C='C', D='D'), 
+                NP(RemoveNodes(c7, 'E', method='secondary'), 'node'))
+
+    # 56 - 25 = 31 nodes remain
+    AssertEqual(31, NumberOfNodes(RemoveNodes(TL84, BasalNodes(TL84))))
+    AssertEqual(14, NumberOfNodes(RemoveNodes(TL84, BasalNodes(TL84), method='secondary')))
+    cascaded <- NumberOfNodes(RemoveNodes(TL84, BasalNodes(TL84), method='cascade'))
+    AssertEqual(6, cascaded)
+    isolated <- c('Asterionella formosa','Chrysosphaerella longispina',
+                  'Diceras sp.', 'Rhizosolenia sp.', 'Spinocosmarium sp.',
+                  'Staurastrum sp.')
+    AssertEqual(isolated, IsolatedNodes(TL84))
 }
 
 TestRemoveIsolatedNodes <- function()
@@ -943,7 +981,7 @@ TestNumberOfNodesByClass <- function()
                 NumberOfNodesByClass(BroadstoneStream))
 }
 
-FractionOfNodesByClass <- function()
+TestFractionOfNodesByClass <- function()
 {
     AssertEqual(c(invertebrate=0.39285714285714284921, 
                   producer=0.55357142857142860315, 
